// ComboBoxOrder.cpp: implementation of the CComboBoxOrder class.
// Copyright (c) 2016 by David Wincelberg
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "ComboBoxOrder.h"

#include "ComboBoxData.h"
#include "StringOrder.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

// Note:	These parameters relate to the Strategy and Flyweight patterns.
CComboBoxOrder::CComboBoxOrder (CStringOrder* pStringOrder /* = nullptr */,
								bool bHandleDelete /* = true */)
{
	m_pStringOrder  = (pStringOrder == nullptr ? new CStringOrder() : pStringOrder);
	m_bHandleDelete = bHandleDelete;
}


CComboBoxOrder::~CComboBoxOrder()
{
	if (m_bHandleDelete)
		delete m_pStringOrder;
}

//////////////////////////////////////////////////////////////////////
// Operations
//////////////////////////////////////////////////////////////////////

// Action:	Replaces the string-order object.
//			Deletes the old one unless m_bHandleDelete is false.
// Note:	This relates to the Strategy and Flyweight patterns.
void CComboBoxOrder::SetStringOrder (CStringOrder* pStringOrder,
									 bool bHandleDelete /* = true */)
{
	if (pStringOrder == nullptr)
		return;

	if (m_bHandleDelete)
		delete m_pStringOrder;

	m_pStringOrder  = pStringOrder;
	m_bHandleDelete = bHandleDelete;
}	// SetStringOrder


// Action:	Compares two strings using the supplied string order.
// Note:	This virtual function may be replaced for custom ordering.
int CComboBoxOrder::Compare (CString& strItem1, CComboBoxData* pData1,
							 CString& strItem2, CComboBoxData* pData2)
{
	if (!ValidStringOrder())
		return 0;

	return GetStringOrder()->CompareStrings (strItem1, strItem2);
}	// Compare
