// StringSANOrder.cpp: implementation of the CStringSANOrder class.
// Copyright (c) 2017 by David Wincelberg
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "StringSANOrder.h"

#include <cctype>	// for isdigit, tolower
#include <cstdlib>	// for atoi

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CStringSANOrder::CStringSANOrder (bool bLimit /* = false */)
{
	m_bLimit = bLimit;
}


CStringSANOrder::~CStringSANOrder()
{

}

//////////////////////////////////////////////////////////////////////
// Operations
//////////////////////////////////////////////////////////////////////

// Action:	Simple alphanumeric comparisons.
// Notes:	Works when there is a digit in the same starting place in
//			each filename.	Limited to numbers smaller than 2^31,
//			around 2 billion (2,147,483,647).
int CStringSANOrder::CompareStrings (LPCTSTR pszItem1, LPCTSTR pszItem2) const
{
	if (pszItem1 == nullptr || pszItem2 == nullptr)
		return 0;

	register LPCTSTR psz1 = pszItem1;
	register LPCTSTR psz2 = pszItem2;
	int nTest;

	while (*psz1 != _T('\0') && *psz2 != _T('\0')) {
		if (::_istdigit (*psz1) && ::_istdigit (*psz2)) {	// generic for isdigit
			nTest = ::_ttoi (psz1) - ::_ttoi (psz2);		// generic for atoi

			if (nTest != 0)
				return (m_bLimit ? LimitResult (nTest) : nTest);

			// Moves past the numbers.
			while (::_istdigit (*psz1)) ++psz1;
			while (::_istdigit (*psz2)) ++psz2;
		}
		else {
			nTest = ::_totlower (*psz1) - ::_totlower (*psz2);	// generic for tolower

			if (nTest != 0)
				return (m_bLimit ? LimitResult (nTest) : nTest);

			++psz1;
			++psz2;
		}
	}

	nTest = *psz1 - *psz2;	// One string has ended.
	return (m_bLimit ? LimitResult (nTest) : nTest);
}	// CompareStrings
