// TreeCtrlOrder.cpp: implementation of the CTreeCtrlOrder class.
// Copyright (c) 2016 by David Wincelberg
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "TreeCtrlOrder.h"

#include "StringOrder.h"
#include "TreeCtrlData.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

// Note:	These parameters relate to the Strategy and Flyweight patterns.
CTreeCtrlOrder::CTreeCtrlOrder (CStringOrder* pStringOrder /* = nullptr */,
								bool bHandleDelete /* = true */)
{
	m_pStringOrder  = (pStringOrder == nullptr ? new CStringOrder() : pStringOrder);
	m_bHandleDelete = bHandleDelete;
}


CTreeCtrlOrder::~CTreeCtrlOrder()
{
	if (m_bHandleDelete)
		delete m_pStringOrder;
}

//////////////////////////////////////////////////////////////////////
// Operations
//////////////////////////////////////////////////////////////////////

// Action:	Replaces the string-order object.
//			Deletes the old one unless m_bHandleDelete is false.
// Note:	This relates to the Strategy and Flyweight patterns.
void CTreeCtrlOrder::SetStringOrder (CStringOrder* pStringOrder,
									 bool bHandleDelete /* = true */)
{
	if (pStringOrder == nullptr)
		return;

	if (m_bHandleDelete)
		delete m_pStringOrder;

	m_pStringOrder  = pStringOrder;
	m_bHandleDelete = bHandleDelete;
}	// SetStringOrder


// Action:	Compares two strings using the supplied string order.
// Note:	This virtual function may be replaced for custom ordering.
int CTreeCtrlOrder::Compare (LPARAM lParam1, LPARAM lParam2)
{
	if (!ValidStringOrder())
		return 0;

	CTreeCtrlData* pData1 = reinterpret_cast<CTreeCtrlData*> (lParam1);
	CTreeCtrlData* pData2 = reinterpret_cast<CTreeCtrlData*> (lParam2);

	return GetStringOrder()->CompareStrings (pData1->GetText(), pData2->GetText());
}	// Compare
